@@ -39,8 +39,8 @@ def _compile_contract(path):
     cmd = f"""
     starknet-compile {path} \
         --cairo_path={CONTRACTS_DIRECTORY}
-        --output {BUILD_DIRECTORY}{filename}.json \
-        --abi {ABIS_DIRECTORY}{filename}.json
+        --output {BUILD_DIRECTORY}/{filename}.json \
+        --abi {ABIS_DIRECTORY}/{filename}.json
     """
     process = subprocess.Popen(cmd.split(), stdout=subprocess.PIPE)
     output, error = process.communicate()
