@@ -1,10 +1,14 @@
 """nile common module."""
 import os
+import re
 
-CONTRACTS_DIRECTORY = "contracts/"
-BUILD_DIRECTORY = "artifacts/"
-TEMP_DIRECTORY = ".temp/"
-ABIS_DIRECTORY = f"{BUILD_DIRECTORY}abis/"
+CONTRACTS_DIRECTORY = "contracts"
+BUILD_DIRECTORY = "artifacts"
+TEMP_DIRECTORY = ".temp"
+ABIS_DIRECTORY = f"{BUILD_DIRECTORY}/abis"
+DEPLOYMENTS_FILENAME = "deployments.txt"
+
+GATEWAYS = {"localhost": "http://localhost:5000/"}
 
 
 def get_all_contracts(ext=None):
@@ -17,3 +21,8 @@ def get_all_contracts(ext=None):
         files += [os.path.join(dirpath, file) for file in filenames]
 
     return filter(lambda file: file.endswith(ext), files)
+
+
+def get_address_from(x):
+    """Extract an address from a string if exists."""
+    return re.findall("0x[\\da-f]{64}", str(x))[0]
